@@ -50,7 +50,7 @@ sub import {
 
 1;
 
-our $VERSION = '0.0192';    # VERSION
+our $VERSION = '0.0193';    # VERSION
 
 # ABSTRACT: Evo - the next generation component-oriented development framework
 
@@ -66,7 +66,7 @@ Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0192
+version 0.0193
 
 =head1 DESCRIPTION
 
@@ -85,7 +85,7 @@ Post modern component oriented programming L<Evo::Comp> instead of OO
 (no docs yet) Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
 
 =item *
-Fast non recursive L<Evo::Promises>, 100% "Promises/Spec A" compatible
+Fast non recursive L<Evo::Promise>, 100% "Promise/Spec A" compatible
 
 =item *
 Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws. Testable and mockable alternative of the global class
@@ -134,7 +134,7 @@ Shortcuts are used to make life easily during code refactoring (and you module s
 
 C<-> is replaced by C<Evo>
 
-  use Evo '-Promises promise'; # "Evo::Promises promise"
+  use Evo '-Promise promise'; # "Evo::Promise promise"
 
 C<:> and C<::> make sense in the package and depends on the package name where is used
 
